[gtranslator] Refactor methods from gtranslator to gtr on plugins.
- From: Ignacio Casal Quinteiro <icq src gnome org>
- To: svn-commits-list gnome org
- Cc:
- Subject: [gtranslator] Refactor methods from gtranslator to gtr on plugins.
- Date: Sun, 7 Feb 2010 21:09:33 +0000 (UTC)
commit 9f57ef4c80587da0fc735435ef892924792247e6
Author: Ignacio Casal Quinteiro <icq gnome org>
Date: Sun Feb 7 22:06:43 2010 +0100
Refactor methods from gtranslator to gtr on plugins.
.../gtr-alternate-language-panel.c | 54 ++++++------
.../gtr-alternate-language-panel.h | 8 +-
.../gtr-alternate-language-plugin.c | 40 ++++----
.../gtr-alternate-language-plugin.h | 6 +-
plugins/charmap/gtr-charmap-panel.c | 20 ++--
plugins/charmap/gtr-charmap-panel.h | 20 ++--
plugins/charmap/gtr-charmap-plugin.c | 52 ++++++------
plugins/charmap/gtr-charmap-plugin.h | 10 +-
plugins/dictionary/gtr-dict-panel.c | 92 ++++++++++----------
plugins/dictionary/gtr-dict-panel.h | 10 +-
plugins/dictionary/gtr-dictionary-plugin.c | 22 +++---
plugins/dictionary/gtr-dictionary-plugin.h | 6 +-
plugins/fullscreen/gtr-fullscreen-plugin.c | 16 ++--
plugins/fullscreen/gtr-fullscreen-plugin.h | 6 +-
plugins/glossary/glossary-panel.c | 18 ++--
plugins/glossary/glossary-panel.h | 16 ++--
plugins/insert-params/gtr-insert-params-plugin.c | 32 ++++----
plugins/insert-params/gtr-insert-params-plugin.h | 6 +-
plugins/insert-tags/gtr-insert-tags-plugin.c | 32 ++++----
plugins/insert-tags/gtr-insert-tags-plugin.h | 6 +-
plugins/open-tran/gtr-open-tran-panel.c | 22 +++---
plugins/open-tran/gtr-open-tran-panel.h | 10 +-
plugins/open-tran/gtr-open-tran-plugin.c | 26 +++---
plugins/open-tran/gtr-open-tran-plugin.h | 6 +-
.../source-code-view/gtr-source-code-view-plugin.c | 62 +++++++-------
.../source-code-view/gtr-source-code-view-plugin.h | 6 +-
plugins/source-code-view/gtr-viewer.c | 18 ++--
plugins/source-code-view/gtr-viewer.h | 8 +-
28 files changed, 315 insertions(+), 315 deletions(-)
---
diff --git a/plugins/alternate-language/gtr-alternate-language-panel.c b/plugins/alternate-language/gtr-alternate-language-panel.c
index 154bf16..b73108e 100644
--- a/plugins/alternate-language/gtr-alternate-language-panel.c
+++ b/plugins/alternate-language/gtr-alternate-language-panel.c
@@ -42,7 +42,7 @@
GtrAlternateLangPanelPrivate))
GTR_PLUGIN_DEFINE_TYPE (GtrAlternateLangPanel,
- gtranslator_alternate_lang_panel, GTK_TYPE_VBOX)
+ gtr_alternate_lang_panel, GTK_TYPE_VBOX)
struct _GtrAlternateLangPanelPrivate
{
GtkWidget *open_button;
@@ -57,7 +57,7 @@ GTR_PLUGIN_DEFINE_TYPE (GtrAlternateLangPanel,
};
static void
- gtranslator_alternate_lang_panel_set_text
+ gtr_alternate_lang_panel_set_text
(GtrAlternateLangPanel * panel, const gchar * text)
{
GtkTextBuffer *buf;
@@ -72,25 +72,25 @@ search_message (GtrAlternateLangPanel * panel, GtrMsg * msg)
{
GList *messages;
GList *l;
- const gchar *msgid = gtranslator_msg_get_msgid (msg);
+ const gchar *msgid = gtr_msg_get_msgid (msg);
gchar *msgid_collate;
const gchar *string;
gchar *string_collate;
GtrMsgStatus status;
msgid_collate = g_utf8_collate_key (msgid, -1);
- messages = gtranslator_po_get_messages (panel->priv->po);
+ messages = gtr_po_get_messages (panel->priv->po);
l = messages;
do
{
- string = gtranslator_msg_get_msgid (l->data);
+ string = gtr_msg_get_msgid (l->data);
string_collate = g_utf8_collate_key (string, -1);
if (strcmp (string_collate, msgid_collate) == 0)
{
- gtranslator_alternate_lang_panel_set_text (panel,
- gtranslator_msg_get_msgstr
+ gtr_alternate_lang_panel_set_text (panel,
+ gtr_msg_get_msgstr
(l->data));
- status = gtranslator_msg_get_status (GTR_MSG (l->data));
+ status = gtr_msg_get_status (GTR_MSG (l->data));
switch (status)
{
case GTR_MSG_STATUS_TRANSLATED:
@@ -114,7 +114,7 @@ search_message (GtrAlternateLangPanel * panel, GtrMsg * msg)
while ((l = g_list_next (l)));
g_free (msgid_collate);
- gtranslator_alternate_lang_panel_set_text (panel, _("Message not found"));
+ gtr_alternate_lang_panel_set_text (panel, _("Message not found"));
/*
* If we are here the status is untranslated
@@ -146,8 +146,8 @@ open_file (GtkWidget * dialog, GtrAlternateLangPanel * panel)
file = g_file_new_for_path (po_file);
g_free (po_file);
- panel->priv->po = gtranslator_po_new ();
- gtranslator_po_parse (panel->priv->po, file, &error);
+ panel->priv->po = gtr_po_new ();
+ gtr_po_parse (panel->priv->po, file, &error);
g_object_unref (file);
@@ -175,7 +175,7 @@ open_file (GtkWidget * dialog, GtrAlternateLangPanel * panel)
static void
-gtranslator_file_chooser_analyse (gpointer dialog,
+gtr_file_chooser_analyse (gpointer dialog,
GtrAlternateLangPanel * panel)
{
gint reply;
@@ -215,14 +215,14 @@ open_button_clicked_cb (GtkWidget * open_button,
/*
* I need a way here to get the window
*/
- dialog = gtranslator_file_chooser_new (NULL,
+ dialog = gtr_file_chooser_new (NULL,
FILESEL_OPEN,
_
("Open file for alternate language"),
NULL);
- tab_po = gtranslator_tab_get_po (panel->priv->tab);
- location = gtranslator_po_get_location (tab_po);
+ tab_po = gtr_tab_get_po (panel->priv->tab);
+ location = gtr_po_get_location (tab_po);
parent = g_file_get_parent (location);
g_object_unref (location);
@@ -234,7 +234,7 @@ open_button_clicked_cb (GtkWidget * open_button,
gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), TRUE);
- gtranslator_file_chooser_analyse ((gpointer) dialog, panel);
+ gtr_file_chooser_analyse ((gpointer) dialog, panel);
}
static void
@@ -243,7 +243,7 @@ close_button_clicked_cb (GtkWidget * close_button,
{
if (panel->priv->po != NULL)
{
- gtranslator_alternate_lang_panel_set_text (panel, _("File closed"));
+ gtr_alternate_lang_panel_set_text (panel, _("File closed"));
gtk_widget_set_sensitive (panel->priv->textview, FALSE);
@@ -254,7 +254,7 @@ close_button_clicked_cb (GtkWidget * close_button,
}
static void
-gtranslator_alternate_lang_panel_draw (GtrAlternateLangPanel * panel)
+gtr_alternate_lang_panel_draw (GtrAlternateLangPanel * panel)
{
GtkWidget *hbox;
GtkWidget *buttonbox;
@@ -305,11 +305,11 @@ gtranslator_alternate_lang_panel_draw (GtrAlternateLangPanel * panel)
scroll = gtk_scrolled_window_new (NULL, NULL);
gtk_widget_show (scroll);
- panel->priv->textview = gtranslator_view_new ();
+ panel->priv->textview = gtr_view_new ();
gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (panel->priv->textview),
GTK_WRAP_WORD);
gtk_text_view_set_editable (GTK_TEXT_VIEW (panel->priv->textview), FALSE);
- gtranslator_alternate_lang_panel_set_text (panel,
+ gtr_alternate_lang_panel_set_text (panel,
_
("There isn't any file loaded"));
gtk_widget_set_sensitive (panel->priv->textview, FALSE);
@@ -327,24 +327,24 @@ gtranslator_alternate_lang_panel_draw (GtrAlternateLangPanel * panel)
}
static void
-gtranslator_alternate_lang_panel_init (GtrAlternateLangPanel * panel)
+gtr_alternate_lang_panel_init (GtrAlternateLangPanel * panel)
{
panel->priv = GTR_ALTERNATE_LANG_PANEL_GET_PRIVATE (panel);
- gtranslator_alternate_lang_panel_draw (panel);
+ gtr_alternate_lang_panel_draw (panel);
panel->priv->po = NULL;
}
static void
-gtranslator_alternate_lang_panel_finalize (GObject * object)
+gtr_alternate_lang_panel_finalize (GObject * object)
{
- G_OBJECT_CLASS (gtranslator_alternate_lang_panel_parent_class)->
+ G_OBJECT_CLASS (gtr_alternate_lang_panel_parent_class)->
finalize (object);
}
static void
-gtranslator_alternate_lang_panel_class_init
+gtr_alternate_lang_panel_class_init
(GtrAlternateLangPanelClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
@@ -352,13 +352,13 @@ gtranslator_alternate_lang_panel_class_init
g_type_class_add_private (klass,
sizeof (GtrAlternateLangPanelPrivate));
- object_class->finalize = gtranslator_alternate_lang_panel_finalize;
+ object_class->finalize = gtr_alternate_lang_panel_finalize;
}
/***************************** Public funcs ***********************************/
GtkWidget *
-gtranslator_alternate_lang_panel_new (GtkWidget * tab)
+gtr_alternate_lang_panel_new (GtkWidget * tab)
{
GtrAlternateLangPanel *panel;
panel = g_object_new (GTR_TYPE_ALTERNATE_LANG_PANEL, NULL);
diff --git a/plugins/alternate-language/gtr-alternate-language-panel.h b/plugins/alternate-language/gtr-alternate-language-panel.h
index 828584f..2efb650 100644
--- a/plugins/alternate-language/gtr-alternate-language-panel.h
+++ b/plugins/alternate-language/gtr-alternate-language-panel.h
@@ -26,7 +26,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_ALTERNATE_LANG_PANEL (gtranslator_alternate_lang_panel_get_type ())
+#define GTR_TYPE_ALTERNATE_LANG_PANEL (gtr_alternate_lang_panel_get_type ())
#define GTR_ALTERNATE_LANG_PANEL(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_ALTERNATE_LANG_PANEL, GtrAlternateLangPanel))
#define GTR_ALTERNATE_LANG_PANEL_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_ALTERNATE_LANG_PANEL, GtrAlternateLangPanelClass))
#define GTR_IS_ALTERNATE_LANG_PANEL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_ALTERNATE_LANG_PANEL))
@@ -64,11 +64,11 @@ struct _GtrAlternateLangPanelClass
* Public methods
*/
GType
-gtranslator_alternate_lang_panel_get_type (void)
+gtr_alternate_lang_panel_get_type (void)
G_GNUC_CONST;
- GType gtranslator_alternate_lang_panel_register_type (GTypeModule *
+ GType gtr_alternate_lang_panel_register_type (GTypeModule *
module);
- GtkWidget *gtranslator_alternate_lang_panel_new (GtkWidget * tab);
+ GtkWidget *gtr_alternate_lang_panel_new (GtkWidget * tab);
G_END_DECLS
#endif /* __ALTERNATE_LANG_PANEL_H__ */
diff --git a/plugins/alternate-language/gtr-alternate-language-plugin.c b/plugins/alternate-language/gtr-alternate-language-plugin.c
index 422fb9b..677e5f2 100644
--- a/plugins/alternate-language/gtr-alternate-language-plugin.c
+++ b/plugins/alternate-language/gtr-alternate-language-plugin.c
@@ -37,8 +37,8 @@
GtrAlternateLangPluginPrivate))
GTR_PLUGIN_REGISTER_TYPE_WITH_CODE (GtrAlternateLangPlugin,
- gtranslator_alternate_lang_plugin,
- gtranslator_alternate_lang_panel_register_type
+ gtr_alternate_lang_plugin,
+ gtr_alternate_lang_panel_register_type
(module);)
static void on_alternate_lang_activated (GtkAction * action,
GtrWindow * window)
@@ -46,10 +46,10 @@ GTR_PLUGIN_REGISTER_TYPE_WITH_CODE (GtrAlternateLangPlugin,
GtrTab *tab;
GtkWidget *alternatelang;
- tab = gtranslator_window_get_active_tab (window);
+ tab = gtr_window_get_active_tab (window);
alternatelang = g_object_get_data (G_OBJECT (tab), TAB_DATA_KEY);
- gtranslator_tab_show_lateral_panel_widget (GTR_TAB (tab), alternatelang);
+ gtr_tab_show_lateral_panel_widget (GTR_TAB (tab), alternatelang);
}
static const GtkActionEntry action_entries[] = {
@@ -78,22 +78,22 @@ update_ui_real (GtrWindow * window, WindowData * data)
GtrTab *tab;
GtkAction *action;
- tab = gtranslator_window_get_active_tab (window);
+ tab = gtr_window_get_active_tab (window);
action = gtk_action_group_get_action (data->action_group, "AlternateLang");
gtk_action_set_sensitive (action, (tab != NULL));
}
static void
-gtranslator_alternate_lang_plugin_init (GtrAlternateLangPlugin *
+gtr_alternate_lang_plugin_init (GtrAlternateLangPlugin *
message_table)
{
}
static void
-gtranslator_alternate_lang_plugin_finalize (GObject * object)
+gtr_alternate_lang_plugin_finalize (GObject * object)
{
- G_OBJECT_CLASS (gtranslator_alternate_lang_plugin_parent_class)->
+ G_OBJECT_CLASS (gtr_alternate_lang_plugin_parent_class)->
finalize (object);
}
@@ -107,14 +107,14 @@ create_alternate_lang_plugin_panel (GtkNotebook * notebook,
GtkWidget *alternatelang;
GtrPo *po;
- po = gtranslator_tab_get_po (GTR_TAB (child));
+ po = gtr_tab_get_po (GTR_TAB (child));
g_return_if_fail (po != NULL);
- alternatelang = gtranslator_alternate_lang_panel_new (child);
+ alternatelang = gtr_alternate_lang_panel_new (child);
gtk_widget_show (alternatelang);
- gtranslator_tab_add_widget_to_lateral_panel (GTR_TAB (child),
+ gtr_tab_add_widget_to_lateral_panel (GTR_TAB (child),
alternatelang,
_("Alternate Language"));
@@ -131,7 +131,7 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
data = g_new (WindowData, 1);
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data->action_group =
gtk_action_group_new ("GtrAlternateLangPluginActions");
@@ -154,13 +154,13 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
"AlternateLang",
"AlternateLang", GTK_UI_MANAGER_MENUITEM, FALSE);
- notebook = gtranslator_window_get_notebook (window);
+ notebook = gtr_window_get_notebook (window);
g_signal_connect (GTK_NOTEBOOK (notebook),
"page-added",
G_CALLBACK (create_alternate_lang_plugin_panel), window);
- tabs = gtranslator_window_get_all_tabs (window);
+ tabs = gtr_window_get_all_tabs (window);
if (tabs == NULL)
return;
@@ -181,8 +181,8 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
GtkUIManager *manager;
WindowData *data;
- tabs = gtranslator_window_get_all_tabs (window);
- notebook = gtranslator_window_get_notebook (window);
+ tabs = gtr_window_get_all_tabs (window);
+ notebook = gtr_window_get_notebook (window);
if (tabs != NULL)
{
@@ -190,7 +190,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
{
alternatelang =
g_object_get_data (G_OBJECT (tabs->data), TAB_DATA_KEY);
- gtranslator_tab_remove_widget_from_lateral_panel (GTR_TAB
+ gtr_tab_remove_widget_from_lateral_panel (GTR_TAB
(tabs->data),
alternatelang);
@@ -204,7 +204,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
window);
/* Remove menuitem */
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data =
(WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
@@ -229,13 +229,13 @@ impl_update_ui (GtrPlugin * plugin, GtrWindow * window)
}
static void
-gtranslator_alternate_lang_plugin_class_init
+gtr_alternate_lang_plugin_class_init
(GtrAlternateLangPluginClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_alternate_lang_plugin_finalize;
+ object_class->finalize = gtr_alternate_lang_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/alternate-language/gtr-alternate-language-plugin.h b/plugins/alternate-language/gtr-alternate-language-plugin.h
index edd9003..2fc8f49 100644
--- a/plugins/alternate-language/gtr-alternate-language-plugin.h
+++ b/plugins/alternate-language/gtr-alternate-language-plugin.h
@@ -29,7 +29,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_ALTERNATE_LANG_PLUGIN (gtranslator_alternate_lang_get_type ())
+#define GTR_TYPE_ALTERNATE_LANG_PLUGIN (gtr_alternate_lang_get_type ())
#define GTR_ALTERNATE_LANG_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_MESSAGEALTERNATE_LANG_PLUGIN, GtrAlternateLangPlugin))
#define GTR_ALTERNATE_LANG_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_ALTERNATE_LANG_PLUGIN, GtrAlternateLangPluginClass))
#define GTR_IS_ALTERNATE_LANG_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_ALTERNATE_LANG_PLUGIN))
@@ -64,11 +64,11 @@ struct _GtrAlternateLangPluginClass
* Public methods
*/
GType
-gtranslator_alternate_lang_plugin_get_type (void)
+gtr_alternate_lang_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_ALTERNATE_LANG_PLUGIN_H__ */
diff --git a/plugins/charmap/gtr-charmap-panel.c b/plugins/charmap/gtr-charmap-panel.c
index be3ecc2..4c788ee 100644
--- a/plugins/charmap/gtr-charmap-panel.c
+++ b/plugins/charmap/gtr-charmap-panel.c
@@ -1,5 +1,5 @@
/*
- * gtranslator-charmap-panel.c
+ * gtr-charmap-panel.c
*
* Copyright (C) 2006 Steve Frécinaux
*
@@ -47,7 +47,7 @@ struct _GtrCharmapPanelPrivate
#endif
};
-GTR_PLUGIN_DEFINE_TYPE (GtrCharmapPanel, gtranslator_charmap_panel,
+GTR_PLUGIN_DEFINE_TYPE (GtrCharmapPanel, gtr_charmap_panel,
GTK_TYPE_VBOX)
#ifdef HAVE_GUCHARMAP_2
static void
@@ -79,7 +79,7 @@ GTR_PLUGIN_DEFINE_TYPE (GtrCharmapPanel, gtranslator_charmap_panel,
#endif /* HAVE_GUCHARMAP_2 */
static void
-gtranslator_charmap_panel_init (GtrCharmapPanel * panel)
+gtr_charmap_panel_init (GtrCharmapPanel * panel)
{
GtrCharmapPanelPrivate *priv;
GtkPaned *paned;
@@ -162,36 +162,36 @@ gtranslator_charmap_panel_init (GtrCharmapPanel * panel)
}
static void
-gtranslator_charmap_panel_finalize (GObject * object)
+gtr_charmap_panel_finalize (GObject * object)
{
- G_OBJECT_CLASS (gtranslator_charmap_panel_parent_class)->finalize (object);
+ G_OBJECT_CLASS (gtr_charmap_panel_parent_class)->finalize (object);
}
static void
-gtranslator_charmap_panel_class_init (GtrCharmapPanelClass * klass)
+gtr_charmap_panel_class_init (GtrCharmapPanelClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
g_type_class_add_private (klass, sizeof (GtrCharmapPanelPrivate));
- object_class->finalize = gtranslator_charmap_panel_finalize;
+ object_class->finalize = gtr_charmap_panel_finalize;
}
GtkWidget *
-gtranslator_charmap_panel_new (void)
+gtr_charmap_panel_new (void)
{
return GTK_WIDGET (g_object_new (GTR_TYPE_CHARMAP_PANEL, NULL));
}
#ifdef HAVE_GUCHARMAP_2
GucharmapChartable *
-gtranslator_charmap_panel_get_chartable (GtrCharmapPanel * panel)
+gtr_charmap_panel_get_chartable (GtrCharmapPanel * panel)
{
return panel->priv->chartable;
}
#else
GucharmapTable *
-gtranslator_charmap_panel_get_table (GtrCharmapPanel * panel)
+gtr_charmap_panel_get_table (GtrCharmapPanel * panel)
{
return GUCHARMAP_TABLE (panel->priv->table);
}
diff --git a/plugins/charmap/gtr-charmap-plugin.c b/plugins/charmap/gtr-charmap-plugin.c
index 4d5f6f1..bc384b1 100644
--- a/plugins/charmap/gtr-charmap-plugin.c
+++ b/plugins/charmap/gtr-charmap-plugin.c
@@ -1,5 +1,5 @@
/*
- * gtranslator-charmap-plugin.c - Character map side-pane for gtranslator
+ * gtr-charmap-plugin.c - Character map side-pane for gtr
*
* Copyright (C) 2006 Steve Frécinaux
*
@@ -52,21 +52,21 @@ typedef struct
} WindowData;
GTR_PLUGIN_REGISTER_TYPE_WITH_CODE (GtrCharmapPlugin,
- gtranslator_charmap_plugin,
- gtranslator_charmap_panel_register_type
+ gtr_charmap_plugin,
+ gtr_charmap_panel_register_type
(module);)
- static void gtranslator_charmap_plugin_init (GtrCharmapPlugin *
+ static void gtr_charmap_plugin_init (GtrCharmapPlugin *
plugin)
{
- //gtranslator_debug_message (DEBUG_PLUGINS, "GtrCharmapPlugin initializing");
+ //gtr_debug_message (DEBUG_PLUGINS, "GtrCharmapPlugin initializing");
}
static void
-gtranslator_charmap_plugin_finalize (GObject * object)
+gtr_charmap_plugin_finalize (GObject * object)
{
- //gtranslator_debug_message (DEBUG_PLUGINS, "GtrCharmapPlugin finalizing");
+ //gtr_debug_message (DEBUG_PLUGINS, "GtrCharmapPlugin finalizing");
- G_OBJECT_CLASS (gtranslator_charmap_plugin_parent_class)->finalize (object);
+ G_OBJECT_CLASS (gtr_charmap_plugin_parent_class)->finalize (object);
}
static void
@@ -86,15 +86,15 @@ on_table_status_message (GucharmapTable * chartable,
GtrStatusbar *statusbar;
WindowData *data;
- statusbar = GTR_STATUSBAR (gtranslator_window_get_statusbar (window));
+ statusbar = GTR_STATUSBAR (gtr_window_get_statusbar (window));
data = (WindowData *) g_object_get_data (G_OBJECT (window),
WINDOW_DATA_KEY);
g_return_if_fail (data != NULL);
- gtranslator_statusbar_pop (statusbar, data->context_id);
+ gtr_statusbar_pop (statusbar, data->context_id);
if (message)
- gtranslator_statusbar_push (statusbar, data->context_id, message);
+ gtr_statusbar_push (statusbar, data->context_id, message);
}
static void
@@ -157,10 +157,10 @@ on_table_focus_out_event (GtkWidget * drawing_area,
g_return_val_if_fail (data != NULL, FALSE);
#ifdef HAVE_GUCHARMAP_2
- chartable = gtranslator_charmap_panel_get_chartable
+ chartable = gtr_charmap_panel_get_chartable
(GTR_CHARMAP_PANEL (data->panel));
#else
- chartable = gtranslator_charmap_panel_get_table
+ chartable = gtr_charmap_panel_get_table
(GTR_CHARMAP_PANEL (data->panel));
#endif
@@ -190,7 +190,7 @@ on_table_activate (GucharmapTable * chartable,
g_return_if_fail (gucharmap_unichar_validate (wc));
- view = GTK_TEXT_VIEW (gtranslator_window_get_active_view (window));
+ view = GTK_TEXT_VIEW (gtr_window_get_active_view (window));
if (!view || !gtk_text_view_get_editable (view))
return;
@@ -222,13 +222,13 @@ create_charmap_panel (GtrWindow * window)
GucharmapTable *table;
#endif
- panel = gtranslator_charmap_panel_new ();
+ panel = gtr_charmap_panel_new ();
#ifdef HAVE_GUCHARMAP_2
chartable =
- gtranslator_charmap_panel_get_chartable (GTR_CHARMAP_PANEL (panel));
+ gtr_charmap_panel_get_chartable (GTR_CHARMAP_PANEL (panel));
#else
- table = gtranslator_charmap_panel_get_table (GTR_CHARMAP_PANEL (panel));
+ table = gtr_charmap_panel_get_table (GTR_CHARMAP_PANEL (panel));
#endif
#ifdef HAVE_GUCHARMAP_2
@@ -272,20 +272,20 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
data = g_new (WindowData, 1);
- gtranslator_application_register_icon (GTR_APP, "gucharmap.ico",
+ gtr_application_register_icon (GTR_APP, "gucharmap.ico",
"charmap-plugin-icon");
data->panel = create_charmap_panel (window);
- gtranslator_window_add_widget (window,
+ gtr_window_add_widget (window,
data->panel,
"GtrCharmapPlugin",
_("Character Map"),
"charmap-plugin-icon",
GTR_WINDOW_PLACEMENT_LEFT);
- statusbar = GTR_STATUSBAR (gtranslator_window_get_statusbar (window));
- data->context_id = gtranslator_statusbar_get_context_id (statusbar,
+ statusbar = GTR_STATUSBAR (gtr_window_get_statusbar (window));
+ data->context_id = gtr_statusbar_get_context_id (statusbar,
"Character Description");
g_object_set_data_full (G_OBJECT (window),
@@ -308,27 +308,27 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
g_return_if_fail (data != NULL);
#ifdef HAVE_GUCHARMAP_2
- chartable = gtranslator_charmap_panel_get_chartable
+ chartable = gtr_charmap_panel_get_chartable
(GTR_CHARMAP_PANEL (data->panel));
#else
- chartable = gtranslator_charmap_panel_get_table
+ chartable = gtr_charmap_panel_get_table
(GTR_CHARMAP_PANEL (data->panel));
#endif
on_table_status_message (chartable, NULL, window);
- gtranslator_window_remove_widget (window, data->panel);
+ gtr_window_remove_widget (window, data->panel);
g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
}
static void
-gtranslator_charmap_plugin_class_init (GtrCharmapPluginClass * klass)
+gtr_charmap_plugin_class_init (GtrCharmapPluginClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_charmap_plugin_finalize;
+ object_class->finalize = gtr_charmap_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/dictionary/gtr-dict-panel.c b/plugins/dictionary/gtr-dict-panel.c
index e4aebd5..36d7662 100644
--- a/plugins/dictionary/gtr-dict-panel.c
+++ b/plugins/dictionary/gtr-dict-panel.c
@@ -39,7 +39,7 @@
GTR_TYPE_DICT_PANEL, \
GtrDictPanelPrivate))
-#define DICTIONARY_GCONF_DIR "/apps/gtranslator/plugins/dictionary"
+#define DICTIONARY_GCONF_DIR "/apps/gtr/plugins/dictionary"
#define DICTIONARY_GCONF_DATABASE_KEY DICTIONARY_GCONF_DIR "/database"
#define DICTIONARY_GCONF_STRATEGY_KEY DICTIONARY_GCONF_DIR "/strategy"
#define DICTIONARY_DEFAULT_SOURCE_NAME "Default"
@@ -52,7 +52,7 @@
#define GDICT_SIDEBAR_STRATEGIES_PAGE "strat-chooser"
#define GDICT_SIDEBAR_SOURCES_PAGE "source-chooser"
-GTR_PLUGIN_DEFINE_TYPE (GtrDictPanel, gtranslator_dict_panel,
+GTR_PLUGIN_DEFINE_TYPE (GtrDictPanel, gtr_dict_panel,
GTK_TYPE_VBOX)
struct _GtrDictPanelPrivate
{
@@ -82,7 +82,7 @@ GTR_PLUGIN_DEFINE_TYPE (GtrDictPanel, gtranslator_dict_panel,
};
static void
- gtranslator_dict_panel_create_warning_dialog (const gchar * primary,
+ gtr_dict_panel_create_warning_dialog (const gchar * primary,
const gchar * secondary)
{
GtkWidget *dialog;
@@ -113,7 +113,7 @@ gdict_gconf_get_string_with_default (GConfClient * client,
}
static void
-gtranslator_dict_panel_entry_activate_cb (GtkWidget * widget,
+gtr_dict_panel_entry_activate_cb (GtkWidget * widget,
GtrDictPanel * panel)
{
GtrDictPanelPrivate *priv = panel->priv;
@@ -131,7 +131,7 @@ gtranslator_dict_panel_entry_activate_cb (GtkWidget * widget,
}
static void
-gtranslator_dict_panel_set_database (GtrDictPanel * panel,
+gtr_dict_panel_set_database (GtrDictPanel * panel,
const gchar * database)
{
GtrDictPanelPrivate *priv = panel->priv;
@@ -149,7 +149,7 @@ gtranslator_dict_panel_set_database (GtrDictPanel * panel,
}
static void
-gtranslator_dict_panel_set_strategy (GtrDictPanel * panel,
+gtr_dict_panel_set_strategy (GtrDictPanel * panel,
const gchar * strategy)
{
GtrDictPanelPrivate *priv = panel->priv;
@@ -183,7 +183,7 @@ get_context_from_loader (GtrDictPanel * panel)
g_strdup_printf (_("No dictionary source available with name '%s'"),
priv->source_name);
- gtranslator_dict_panel_create_warning_dialog (_
+ gtr_dict_panel_create_warning_dialog (_
("Unable to find dictionary source"),
detail);
g_free (detail);
@@ -191,9 +191,9 @@ get_context_from_loader (GtrDictPanel * panel)
return NULL;
}
- gtranslator_dict_panel_set_database (panel,
+ gtr_dict_panel_set_database (panel,
gdict_source_get_database (source));
- gtranslator_dict_panel_set_strategy (panel,
+ gtr_dict_panel_set_strategy (panel,
gdict_source_get_strategy (source));
retval = gdict_source_get_context (source);
@@ -204,7 +204,7 @@ get_context_from_loader (GtrDictPanel * panel)
detail = g_strdup_printf (_("No context available for source '%s'"),
gdict_source_get_description (source));
- gtranslator_dict_panel_create_warning_dialog (_
+ gtr_dict_panel_create_warning_dialog (_
("Unable to create a context"),
detail);
@@ -220,7 +220,7 @@ get_context_from_loader (GtrDictPanel * panel)
}
static void
-gtranslator_dict_panel_set_context (GtrDictPanel * panel,
+gtr_dict_panel_set_context (GtrDictPanel * panel,
GdictContext * context)
{
GtrDictPanelPrivate *priv = panel->priv;
@@ -249,7 +249,7 @@ gtranslator_dict_panel_set_context (GtrDictPanel * panel,
}
static void
-gtranslator_dict_panel_set_source_name (GtrDictPanel * panel,
+gtr_dict_panel_set_source_name (GtrDictPanel * panel,
const gchar * source_name)
{
GtrDictPanelPrivate *priv = panel->priv;
@@ -270,7 +270,7 @@ gtranslator_dict_panel_set_source_name (GtrDictPanel * panel,
DICTIONARY_DEFAULT_SOURCE_NAME);
context = get_context_from_loader (panel);
- gtranslator_dict_panel_set_context (panel, context);
+ gtr_dict_panel_set_context (panel, context);
if (priv->source_chooser)
gdict_source_chooser_set_current_source (GDICT_SOURCE_CHOOSER
@@ -284,7 +284,7 @@ source_activated_cb (GdictSourceChooser * chooser,
GdictSource * source, GtrDictPanel * panel)
{
g_signal_handlers_block_by_func (chooser, source_activated_cb, panel);
- gtranslator_dict_panel_set_source_name (panel, source_name);
+ gtr_dict_panel_set_source_name (panel, source_name);
g_signal_handlers_unblock_by_func (chooser, source_activated_cb, panel);
if (panel->priv->status)
@@ -293,7 +293,7 @@ source_activated_cb (GdictSourceChooser * chooser,
message = g_strdup_printf (_("Dictionary source '%s' selected"),
gdict_source_get_description (source));
- gtranslator_statusbar_flash_message (panel->priv->status, 0, "%s",
+ gtr_statusbar_flash_message (panel->priv->status, 0, "%s",
message);
g_free (message);
}
@@ -305,14 +305,14 @@ strategy_activated_cb (GdictStrategyChooser * chooser,
const gchar * strat_desc, GtrDictPanel * panel)
{
GtrDictPanelPrivate *priv = panel->priv;
- gtranslator_dict_panel_set_strategy (panel, strat_name);
+ gtr_dict_panel_set_strategy (panel, strat_name);
if (priv->status)
{
gchar *message;
message = g_strdup_printf (_("Strategy '%s' selected"), strat_desc);
- gtranslator_statusbar_flash_message (panel->priv->status, 0, "%s",
+ gtr_statusbar_flash_message (panel->priv->status, 0, "%s",
message);
g_free (message);
}
@@ -324,21 +324,21 @@ database_activated_cb (GdictDatabaseChooser * chooser,
const gchar * db_desc, GtrDictPanel * panel)
{
GtrDictPanelPrivate *priv = panel->priv;
- gtranslator_dict_panel_set_database (panel, db_name);
+ gtr_dict_panel_set_database (panel, db_name);
if (priv->status)
{
gchar *message;
message = g_strdup_printf (_("Database '%s' selected"), db_desc);
- gtranslator_statusbar_flash_message (panel->priv->status, 0, "%s",
+ gtr_statusbar_flash_message (panel->priv->status, 0, "%s",
message);
g_free (message);
}
}
static void
-gtranslator_dict_panel_set_word (GtrDictPanel * panel,
+gtr_dict_panel_set_word (GtrDictPanel * panel,
const gchar * word, const gchar * database)
{
GtrDictPanelPrivate *priv = panel->priv;
@@ -370,14 +370,14 @@ speller_word_activated_cb (GdictSpeller * speller,
GtrDictPanelPrivate *priv = panel->priv;
gtk_entry_set_text (GTK_ENTRY (priv->entry), word);
- gtranslator_dict_panel_set_word (panel, word, db_name);
+ gtr_dict_panel_set_word (panel, word, db_name);
if (priv->status)
{
gchar *message;
message = g_strdup_printf (_("Word '%s' selected"), word);
- gtranslator_statusbar_flash_message (panel->priv->status, 0, "%s",
+ gtr_statusbar_flash_message (panel->priv->status, 0, "%s",
message);
g_free (message);
}
@@ -431,7 +431,7 @@ sidebar_page_changed_cb (GdictSidebar * sidebar, GtrDictPanel * panel)
}
if (message && priv->status)
- gtranslator_statusbar_flash_message (panel->priv->status, 0, "%s",
+ gtr_statusbar_flash_message (panel->priv->status, 0, "%s",
message);
}
@@ -451,7 +451,7 @@ store_position (GObject * gobject, GParamSpec * arg1, gpointer user_data)
}
static void
-gtranslator_dict_panel_link_clicked (GtkWidget * defbox,
+gtr_dict_panel_link_clicked (GtkWidget * defbox,
const gchar * link_text,
GtrDictPanel * panel)
{
@@ -467,7 +467,7 @@ gtranslator_dict_panel_link_clicked (GtkWidget * defbox,
}
static void
-gtranslator_dict_panel_draw (GtrDictPanel * panel)
+gtr_dict_panel_draw (GtrDictPanel * panel)
{
GtkWidget *vbox;
GtkWidget *hbox;
@@ -486,7 +486,7 @@ gtranslator_dict_panel_draw (GtrDictPanel * panel)
*/
panel->priv->button = gtk_button_new_with_mnemonic (_("Look _up:"));
g_signal_connect (panel->priv->button, "clicked",
- G_CALLBACK (gtranslator_dict_panel_entry_activate_cb),
+ G_CALLBACK (gtr_dict_panel_entry_activate_cb),
panel);
gtk_button_set_relief (GTK_BUTTON (panel->priv->button), GTK_RELIEF_NONE);
gtk_box_pack_start (GTK_BOX (hbox), panel->priv->button, FALSE, FALSE, 0);
@@ -500,7 +500,7 @@ gtranslator_dict_panel_draw (GtrDictPanel * panel)
gtk_entry_set_text (GTK_ENTRY (panel->priv->entry), panel->priv->word);
g_signal_connect (panel->priv->entry, "activate",
- G_CALLBACK (gtranslator_dict_panel_entry_activate_cb),
+ G_CALLBACK (gtr_dict_panel_entry_activate_cb),
panel);
gtk_box_pack_start (GTK_BOX (hbox), panel->priv->entry, TRUE, TRUE, 0);
gtk_widget_show (panel->priv->entry);
@@ -514,7 +514,7 @@ gtranslator_dict_panel_draw (GtrDictPanel * panel)
gdict_defbox_set_context (GDICT_DEFBOX (panel->priv->defbox),
panel->priv->context);
g_signal_connect (panel->priv->defbox, "link-clicked",
- G_CALLBACK (gtranslator_dict_panel_link_clicked), panel);
+ G_CALLBACK (gtr_dict_panel_link_clicked), panel);
gtk_container_add (GTK_CONTAINER (vbox), panel->priv->defbox);
gtk_widget_show (panel->priv->defbox);
@@ -605,7 +605,7 @@ gtranslator_dict_panel_draw (GtrDictPanel * panel)
}
static void
-gtranslator_dict_panel_gconf_notify_cb (GConfClient * client,
+gtr_dict_panel_gconf_notify_cb (GConfClient * client,
guint cnxn_id,
GConfEntry * entry,
gpointer user_data)
@@ -615,35 +615,35 @@ gtranslator_dict_panel_gconf_notify_cb (GConfClient * client,
if (strcmp (entry->key, DICTIONARY_GCONF_SOURCE_KEY) == 0)
{
if (entry->value && (entry->value->type == GCONF_VALUE_STRING))
- gtranslator_dict_panel_set_source_name (panel,
+ gtr_dict_panel_set_source_name (panel,
gconf_value_get_string
(entry->value));
else
- gtranslator_dict_panel_set_source_name (panel,
+ gtr_dict_panel_set_source_name (panel,
DICTIONARY_DEFAULT_SOURCE_NAME);
}
else if (strcmp (entry->key, DICTIONARY_GCONF_DATABASE_KEY) == 0)
{
if (entry->value && (entry->value->type == GCONF_VALUE_STRING))
- gtranslator_dict_panel_set_database (panel,
+ gtr_dict_panel_set_database (panel,
gconf_value_get_string (entry->
value));
else
- gtranslator_dict_panel_set_database (panel, GDICT_DEFAULT_DATABASE);
+ gtr_dict_panel_set_database (panel, GDICT_DEFAULT_DATABASE);
}
else if (strcmp (entry->key, DICTIONARY_GCONF_STRATEGY_KEY) == 0)
{
if (entry->value && (entry->value->type == GCONF_VALUE_STRING))
- gtranslator_dict_panel_set_strategy (panel,
+ gtr_dict_panel_set_strategy (panel,
gconf_value_get_string (entry->
value));
else
- gtranslator_dict_panel_set_strategy (panel, GDICT_DEFAULT_STRATEGY);
+ gtr_dict_panel_set_strategy (panel, GDICT_DEFAULT_STRATEGY);
}
}
static void
-gtranslator_dict_panel_init (GtrDictPanel * panel)
+gtr_dict_panel_init (GtrDictPanel * panel)
{
gchar *data_dir;
GtrDictPanelPrivate *priv;
@@ -658,7 +658,7 @@ gtranslator_dict_panel_init (GtrDictPanel * panel)
panel->priv->loader = gdict_source_loader_new ();
/* add our data dir inside $HOME to the loader's search paths */
- data_dir = gtranslator_utils_get_user_config_dir ();
+ data_dir = gtr_utils_get_user_config_dir ();
gdict_source_loader_add_search_path (priv->loader, data_dir);
g_free (data_dir);
@@ -680,7 +680,7 @@ gtranslator_dict_panel_init (GtrDictPanel * panel)
priv->notify_id = gconf_client_notify_add (priv->gconf_client,
DICTIONARY_GCONF_DIR,
- gtranslator_dict_panel_gconf_notify_cb,
+ gtr_dict_panel_gconf_notify_cb,
panel, NULL, &gconf_error);
if (gconf_error)
{
@@ -692,14 +692,14 @@ gtranslator_dict_panel_init (GtrDictPanel * panel)
}
/* force retrieval of the configuration from GConf */
- gtranslator_dict_panel_set_source_name (panel, NULL);
+ gtr_dict_panel_set_source_name (panel, NULL);
/* Draw widgets */
- gtranslator_dict_panel_draw (panel);
+ gtr_dict_panel_draw (panel);
}
static void
-gtranslator_dict_panel_finalize (GObject * object)
+gtr_dict_panel_finalize (GObject * object)
{
GtrDictPanel *panel = GTR_DICT_PANEL (object);
@@ -708,28 +708,28 @@ gtranslator_dict_panel_finalize (GObject * object)
g_free (panel->priv->database);
g_free (panel->priv->strategy);
- G_OBJECT_CLASS (gtranslator_dict_panel_parent_class)->finalize (object);
+ G_OBJECT_CLASS (gtr_dict_panel_parent_class)->finalize (object);
}
static void
-gtranslator_dict_panel_class_init (GtrDictPanelClass * klass)
+gtr_dict_panel_class_init (GtrDictPanelClass * klass)
{
GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
g_type_class_add_private (klass, sizeof (GtrDictPanelPrivate));
- gobject_class->finalize = gtranslator_dict_panel_finalize;
+ gobject_class->finalize = gtr_dict_panel_finalize;
}
GtkWidget *
-gtranslator_dict_panel_new (GtrWindow * window)
+gtr_dict_panel_new (GtrWindow * window)
{
GtrDictPanel *panel;
panel = g_object_new (GTR_TYPE_DICT_PANEL, NULL);
panel->priv->status =
- GTR_STATUSBAR (gtranslator_window_get_statusbar (window));
+ GTR_STATUSBAR (gtr_window_get_statusbar (window));
return GTK_WIDGET (panel);
}
diff --git a/plugins/dictionary/gtr-dict-panel.h b/plugins/dictionary/gtr-dict-panel.h
index 3f73d79..b756616 100644
--- a/plugins/dictionary/gtr-dict-panel.h
+++ b/plugins/dictionary/gtr-dict-panel.h
@@ -28,7 +28,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_DICT_PANEL (gtranslator_dict_panel_get_type ())
+#define GTR_TYPE_DICT_PANEL (gtr_dict_panel_get_type ())
#define GTR_DICT_PANEL(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_DICT_PANEL, GtrDictPanel))
#define GTR_DICT_PANEL_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_DICT_PANEL, GtrDictPanelClass))
#define GTR_IS_DICT_PANEL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_DICT_PANEL))
@@ -64,14 +64,14 @@ struct _GtrDictPanelClass
* Public methods
*/
GType
-gtranslator_dict_panel_get_type (void)
+gtr_dict_panel_get_type (void)
G_GNUC_CONST;
- GType gtranslator_dict_panel_register_type (GTypeModule * module);
+ GType gtr_dict_panel_register_type (GTypeModule * module);
- GtkWidget *gtranslator_dict_panel_new (GtrWindow * window);
+ GtkWidget *gtr_dict_panel_new (GtrWindow * window);
- void gtranslator_dict_panel_set_position (GtrDictPanel * panel,
+ void gtr_dict_panel_set_position (GtrDictPanel * panel,
gint pos);
G_END_DECLS
diff --git a/plugins/dictionary/gtr-dictionary-plugin.c b/plugins/dictionary/gtr-dictionary-plugin.c
index 278acd9..91bd18b 100644
--- a/plugins/dictionary/gtr-dictionary-plugin.c
+++ b/plugins/dictionary/gtr-dictionary-plugin.c
@@ -40,17 +40,17 @@ typedef struct
} WindowData;
GTR_PLUGIN_REGISTER_TYPE_WITH_CODE (GtrDictPlugin,
- gtranslator_dict_plugin,
- gtranslator_dict_panel_register_type
+ gtr_dict_plugin,
+ gtr_dict_panel_register_type
(module);)
- static void gtranslator_dict_plugin_init (GtrDictPlugin * plugin)
+ static void gtr_dict_plugin_init (GtrDictPlugin * plugin)
{
}
static void
-gtranslator_dict_plugin_finalize (GObject * object)
+gtr_dict_plugin_finalize (GObject * object)
{
- G_OBJECT_CLASS (gtranslator_dict_plugin_parent_class)->finalize (object);
+ G_OBJECT_CLASS (gtr_dict_plugin_parent_class)->finalize (object);
}
static void
@@ -67,7 +67,7 @@ create_dict_panel (GtrWindow * window)
{
GtkWidget *panel;
- panel = gtranslator_dict_panel_new (window);
+ panel = gtr_dict_panel_new (window);
gtk_widget_show (panel);
@@ -83,10 +83,10 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
data->panel = create_dict_panel (window);
- gtranslator_application_register_icon (GTR_APP, "gnome-dictionary.png",
+ gtr_application_register_icon (GTR_APP, "gnome-dictionary.png",
"dictionary-icon");
- gtranslator_window_add_widget (window,
+ gtr_window_add_widget (window,
data->panel,
"GtrDictionaryPlugin",
_("Dictionary"),
@@ -107,18 +107,18 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
WINDOW_DATA_KEY);
g_return_if_fail (data != NULL);
- gtranslator_window_remove_widget (window, data->panel);
+ gtr_window_remove_widget (window, data->panel);
g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
}
static void
-gtranslator_dict_plugin_class_init (GtrDictPluginClass * klass)
+gtr_dict_plugin_class_init (GtrDictPluginClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_dict_plugin_finalize;
+ object_class->finalize = gtr_dict_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/dictionary/gtr-dictionary-plugin.h b/plugins/dictionary/gtr-dictionary-plugin.h
index 4e2dcd4..f685932 100644
--- a/plugins/dictionary/gtr-dictionary-plugin.h
+++ b/plugins/dictionary/gtr-dictionary-plugin.h
@@ -27,7 +27,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_DICT_PLUGIN (gtranslator_dict_plugin_get_type ())
+#define GTR_TYPE_DICT_PLUGIN (gtr_dict_plugin_get_type ())
#define GTR_DICT_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_DICT_PLUGIN, GtrDictPlugin))
#define GTR_DICT_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_Dict_PLUGIN, GtrDictPluginClass))
#define GTR_IS_DICT_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_Dict_PLUGIN))
@@ -60,11 +60,11 @@ struct _GtrDictPluginClass
* Public methods
*/
GType
-gtranslator_dict_plugin_get_type (void)
+gtr_dict_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_Dict_PLUGIN_H__ */
diff --git a/plugins/fullscreen/gtr-fullscreen-plugin.c b/plugins/fullscreen/gtr-fullscreen-plugin.c
index 897a0ae..bc0b4b8 100644
--- a/plugins/fullscreen/gtr-fullscreen-plugin.c
+++ b/plugins/fullscreen/gtr-fullscreen-plugin.c
@@ -31,7 +31,7 @@
#define MENU_PATH "/MainMenu/ViewMenu/ViewOps_1"
GTR_PLUGIN_REGISTER_TYPE (GtrFullscreenPlugin,
- gtranslator_fullscreen_plugin)
+ gtr_fullscreen_plugin)
static void on_fullscreen_activated (GtkToggleAction * action,
GtrWindow * window)
{
@@ -62,15 +62,15 @@ free_window_data (WindowData * data)
}
static void
-gtranslator_fullscreen_plugin_init (GtrFullscreenPlugin *
+gtr_fullscreen_plugin_init (GtrFullscreenPlugin *
message_table)
{
}
static void
-gtranslator_fullscreen_plugin_finalize (GObject * object)
+gtr_fullscreen_plugin_finalize (GObject * object)
{
- G_OBJECT_CLASS (gtranslator_fullscreen_plugin_parent_class)->
+ G_OBJECT_CLASS (gtr_fullscreen_plugin_parent_class)->
finalize (object);
}
@@ -85,7 +85,7 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
data = g_new (WindowData, 1);
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data->action_group =
gtk_action_group_new ("GtrFullscreenPluginActions");
@@ -123,7 +123,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
GtkUIManager *manager;
WindowData *data;
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data =
(WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
@@ -136,13 +136,13 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
}
static void
-gtranslator_fullscreen_plugin_class_init (GtrFullscreenPluginClass *
+gtr_fullscreen_plugin_class_init (GtrFullscreenPluginClass *
klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_fullscreen_plugin_finalize;
+ object_class->finalize = gtr_fullscreen_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/fullscreen/gtr-fullscreen-plugin.h b/plugins/fullscreen/gtr-fullscreen-plugin.h
index 734c2eb..bc516af 100644
--- a/plugins/fullscreen/gtr-fullscreen-plugin.h
+++ b/plugins/fullscreen/gtr-fullscreen-plugin.h
@@ -28,7 +28,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_FULLSCREEN_PLUGIN (gtranslator_fullscreen_get_type ())
+#define GTR_TYPE_FULLSCREEN_PLUGIN (gtr_fullscreen_get_type ())
#define GTR_FULLSCREEN_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_MESSAGEFULLSCREEN_PLUGIN, GtrFullscreenPlugin))
#define GTR_FULLSCREEN_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_FULLSCREEN_PLUGIN, GtrFullscreenPluginClass))
#define GTR_IS_FULLSCREEN_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_FULLSCREEN_PLUGIN))
@@ -63,11 +63,11 @@ struct _GtrFullscreenPluginClass
* Public methods
*/
GType
-gtranslator_fullscreen_plugin_get_type (void)
+gtr_fullscreen_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_FULLSCREEN_PLUGIN_H__ */
diff --git a/plugins/glossary/glossary-panel.c b/plugins/glossary/glossary-panel.c
index b794ed6..6960fe7 100644
--- a/plugins/glossary/glossary-panel.c
+++ b/plugins/glossary/glossary-panel.c
@@ -37,7 +37,7 @@
GTR_TYPE_GLOSSARY_PANEL, \
GtrGlossaryPanelPrivate))
-G_DEFINE_TYPE (GtrGlossaryPanel, gtranslator_glossary_panel,
+G_DEFINE_TYPE (GtrGlossaryPanel, gtr_glossary_panel,
GTK_TYPE_VBOX)
#define XML_FILE_NAME "glossary.xml"
/*
@@ -125,7 +125,7 @@ process_node (xmlNode * root_node)
}
static gboolean
-gtranslator_glossary_panel_load_items (GtrGlossaryPanel * panel)
+gtr_glossary_panel_load_items (GtrGlossaryPanel * panel)
{
GtrGlossaryPanelPrivate *priv = panel->priv;
@@ -133,7 +133,7 @@ gtranslator_glossary_panel_load_items (GtrGlossaryPanel * panel)
}
static void
-gtranslator_glossary_panel_draw (GtrGlossaryPanel * panel)
+gtr_glossary_panel_draw (GtrGlossaryPanel * panel)
{
GtrGlossaryPanelPrivate *priv = panel->priv;
@@ -141,7 +141,7 @@ gtranslator_glossary_panel_draw (GtrGlossaryPanel * panel)
}
static void
-gtranslator_glossary_panel_init (GtrGlossaryPanel * panel)
+gtr_glossary_panel_init (GtrGlossaryPanel * panel)
{
panel->priv = GTR_GLOSSARY_PANEL_GET_PRIVATE (panel);
@@ -149,23 +149,23 @@ gtranslator_glossary_panel_init (GtrGlossaryPanel * panel)
}
static void
-gtranslator_glossary_panel_finalize (GObject * object)
+gtr_glossary_panel_finalize (GObject * object)
{
- G_OBJECT_CLASS (gtranslator_glossary_panel_parent_class)->finalize (object);
+ G_OBJECT_CLASS (gtr_glossary_panel_parent_class)->finalize (object);
}
static void
-gtranslator_glossary_panel_class_init (GtrGlossaryPanelClass * klass)
+gtr_glossary_panel_class_init (GtrGlossaryPanelClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
g_type_class_add_private (klass, sizeof (GtrGlossaryPanelPrivate));
- object_class->finalize = gtranslator_glossary_panel_finalize;
+ object_class->finalize = gtr_glossary_panel_finalize;
}
GtkWidget *
-gtranslator_glossary_panel_new (void)
+gtr_glossary_panel_new (void)
{
return GTK_WIDGET (g_object_new (GTR_TYPE_GLOSSARY_PANEL, NULL));
}
diff --git a/plugins/insert-params/gtr-insert-params-plugin.c b/plugins/insert-params/gtr-insert-params-plugin.c
index e994d61..2289b19 100644
--- a/plugins/insert-params/gtr-insert-params-plugin.c
+++ b/plugins/insert-params/gtr-insert-params-plugin.c
@@ -32,7 +32,7 @@
#define WINDOW_DATA_KEY "GtrInsertParamsPluginWindowData"
GTR_PLUGIN_REGISTER_TYPE (GtrInsertParamsPlugin,
- gtranslator_insert_params_plugin)
+ gtr_insert_params_plugin)
static GSList *params = NULL;
static gint param_position;
@@ -58,7 +58,7 @@ GTR_PLUGIN_REGISTER_TYPE (GtrInsertParamsPlugin,
param = g_slist_nth (params, param_position);
- view = gtranslator_window_get_active_view (window);
+ view = gtr_window_get_active_view (window);
buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
@@ -107,7 +107,7 @@ update_ui_real (GtrWindow * window, WindowData * data)
GtkTextView *view;
GtkAction *action;
- view = GTK_TEXT_VIEW (gtranslator_window_get_active_view (window));
+ view = GTK_TEXT_VIEW (gtr_window_get_active_view (window));
action = gtk_action_group_get_action (data->action_group, "InsertParams");
gtk_action_set_sensitive (action,
@@ -121,13 +121,13 @@ update_ui_real (GtrWindow * window, WindowData * data)
}
static void
-gtranslator_insert_params_plugin_init (GtrInsertParamsPlugin *
+gtr_insert_params_plugin_init (GtrInsertParamsPlugin *
message_table)
{
}
static void
-gtranslator_insert_params_plugin_finalize (GObject * object)
+gtr_insert_params_plugin_finalize (GObject * object)
{
if (params != NULL)
{
@@ -135,7 +135,7 @@ gtranslator_insert_params_plugin_finalize (GObject * object)
params = NULL;
}
- G_OBJECT_CLASS (gtranslator_insert_params_plugin_parent_class)->
+ G_OBJECT_CLASS (gtr_insert_params_plugin_parent_class)->
finalize (object);
}
@@ -150,7 +150,7 @@ on_menuitem_activated (GtkMenuItem * item, GtrWindow * window)
label = gtk_bin_get_child (GTK_BIN (item));
name = gtk_label_get_text (GTK_LABEL (label));
- view = gtranslator_window_get_active_view (window);
+ view = gtr_window_get_active_view (window);
buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
@@ -168,7 +168,7 @@ parse_list (GtrWindow * window)
GtkWidget *menu;
GSList *l = params;
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
insert_params = gtk_ui_manager_get_widget (manager,
"/MainMenu/EditMenu/EditOps_1/EditInsertParams");
@@ -225,7 +225,7 @@ showed_message_cb (GtrTab * tab,
*/
param_position = 0;
- msgid = gtranslator_msg_get_msgid (msg);
+ msgid = gtr_msg_get_msgid (msg);
/*
* Regular expression
@@ -285,7 +285,7 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
data = g_new (WindowData, 1);
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data->action_group =
gtk_action_group_new ("GtrInsertParamsPluginActions");
@@ -314,12 +314,12 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
/*Adding menuitems */
- notebook = gtranslator_window_get_notebook (window);
+ notebook = gtr_window_get_notebook (window);
g_signal_connect (GTK_NOTEBOOK (notebook),
"page-added", G_CALLBACK (page_added_cb), window);
- tabs = gtranslator_window_get_all_tabs (window);
+ tabs = gtr_window_get_all_tabs (window);
if (tabs == NULL)
return;
@@ -338,7 +338,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
GtkUIManager *manager;
WindowData *data;
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data =
(WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
@@ -349,7 +349,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
- notebook = gtranslator_window_get_notebook (window);
+ notebook = gtr_window_get_notebook (window);
g_signal_handlers_disconnect_by_func (notebook, page_added_cb, window);
@@ -373,13 +373,13 @@ impl_update_ui (GtrPlugin * plugin, GtrWindow * window)
}
static void
-gtranslator_insert_params_plugin_class_init
+gtr_insert_params_plugin_class_init
(GtrInsertParamsPluginClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_insert_params_plugin_finalize;
+ object_class->finalize = gtr_insert_params_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/insert-params/gtr-insert-params-plugin.h b/plugins/insert-params/gtr-insert-params-plugin.h
index 722e5c2..49cc1e6 100644
--- a/plugins/insert-params/gtr-insert-params-plugin.h
+++ b/plugins/insert-params/gtr-insert-params-plugin.h
@@ -28,7 +28,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_INSERT_PARAMS_PLUGIN (gtranslator_insert_params_get_type ())
+#define GTR_TYPE_INSERT_PARAMS_PLUGIN (gtr_insert_params_get_type ())
#define GTR_INSERT_PARAMS_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_MESSAGEINSERT_PARAMS_PLUGIN, GtrInsertParamsPlugin))
#define GTR_INSERT_PARAMS_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_INSERT_PARAMS_PLUGIN, GtrInsertParamsPluginClass))
#define GTR_IS_INSERT_PARAMS_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_INSERT_PARAMS_PLUGIN))
@@ -63,11 +63,11 @@ struct _GtrInsertParamsPluginClass
* Public methods
*/
GType
-gtranslator_insert_params_plugin_get_type (void)
+gtr_insert_params_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_INSERT_PARAMS_PLUGIN_H__ */
diff --git a/plugins/insert-tags/gtr-insert-tags-plugin.c b/plugins/insert-tags/gtr-insert-tags-plugin.c
index 3aaf6a5..2634302 100644
--- a/plugins/insert-tags/gtr-insert-tags-plugin.c
+++ b/plugins/insert-tags/gtr-insert-tags-plugin.c
@@ -32,7 +32,7 @@
#define WINDOW_DATA_KEY "GtrInsertTagsPluginWindowData"
GTR_PLUGIN_REGISTER_TYPE (GtrInsertTagsPlugin,
- gtranslator_insert_tags_plugin)
+ gtr_insert_tags_plugin)
static GSList *tags = NULL;
static gint tag_position;
@@ -51,7 +51,7 @@ GTR_PLUGIN_REGISTER_TYPE (GtrInsertTagsPlugin,
tag = g_slist_nth (tags, tag_position);
- view = gtranslator_window_get_active_view (window);
+ view = gtr_window_get_active_view (window);
buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
@@ -100,7 +100,7 @@ update_ui_real (GtrWindow * window, WindowData * data)
GtkTextView *view;
GtkAction *action;
- view = GTK_TEXT_VIEW (gtranslator_window_get_active_view (window));
+ view = GTK_TEXT_VIEW (gtr_window_get_active_view (window));
action = gtk_action_group_get_action (data->action_group, "InsertTags");
gtk_action_set_sensitive (action,
@@ -114,13 +114,13 @@ update_ui_real (GtrWindow * window, WindowData * data)
}
static void
-gtranslator_insert_tags_plugin_init (GtrInsertTagsPlugin *
+gtr_insert_tags_plugin_init (GtrInsertTagsPlugin *
message_table)
{
}
static void
-gtranslator_insert_tags_plugin_finalize (GObject * object)
+gtr_insert_tags_plugin_finalize (GObject * object)
{
if (tags != NULL)
{
@@ -128,7 +128,7 @@ gtranslator_insert_tags_plugin_finalize (GObject * object)
tags = NULL;
}
- G_OBJECT_CLASS (gtranslator_insert_tags_plugin_parent_class)->
+ G_OBJECT_CLASS (gtr_insert_tags_plugin_parent_class)->
finalize (object);
}
@@ -143,7 +143,7 @@ on_menuitem_activated (GtkMenuItem * item, GtrWindow * window)
label = gtk_bin_get_child (GTK_BIN (item));
name = gtk_label_get_text (GTK_LABEL (label));
- view = gtranslator_window_get_active_view (window);
+ view = gtr_window_get_active_view (window);
buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
@@ -161,7 +161,7 @@ parse_list (GtrWindow * window)
GtkWidget *menu;
GSList *l = tags;
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
insert_tags = gtk_ui_manager_get_widget (manager,
"/MainMenu/EditMenu/EditOps_1/EditInsertTags");
@@ -217,7 +217,7 @@ showed_message_cb (GtrTab * tab,
*/
tag_position = 0;
- msgid = gtranslator_msg_get_msgid (msg);
+ msgid = gtr_msg_get_msgid (msg);
/*
* Regular expression
@@ -260,7 +260,7 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
data = g_new (WindowData, 1);
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data->action_group =
gtk_action_group_new ("GtrInsertTagsPluginActions");
@@ -289,12 +289,12 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
/*Adding menuitems */
- notebook = gtranslator_window_get_notebook (window);
+ notebook = gtr_window_get_notebook (window);
g_signal_connect (GTK_NOTEBOOK (notebook),
"page-added", G_CALLBACK (page_added_cb), window);
- tabs = gtranslator_window_get_all_tabs (window);
+ tabs = gtr_window_get_all_tabs (window);
if (tabs == NULL)
return;
@@ -313,7 +313,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
GtkUIManager *manager;
WindowData *data;
- manager = gtranslator_window_get_ui_manager (window);
+ manager = gtr_window_get_ui_manager (window);
data =
(WindowData *) g_object_get_data (G_OBJECT (window), WINDOW_DATA_KEY);
@@ -324,7 +324,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
- notebook = gtranslator_window_get_notebook (window);
+ notebook = gtr_window_get_notebook (window);
g_signal_handlers_disconnect_by_func (notebook, page_added_cb, window);
@@ -348,13 +348,13 @@ impl_update_ui (GtrPlugin * plugin, GtrWindow * window)
}
static void
-gtranslator_insert_tags_plugin_class_init (GtrInsertTagsPluginClass *
+gtr_insert_tags_plugin_class_init (GtrInsertTagsPluginClass *
klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_insert_tags_plugin_finalize;
+ object_class->finalize = gtr_insert_tags_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/insert-tags/gtr-insert-tags-plugin.h b/plugins/insert-tags/gtr-insert-tags-plugin.h
index e28d236..eed9a9c 100644
--- a/plugins/insert-tags/gtr-insert-tags-plugin.h
+++ b/plugins/insert-tags/gtr-insert-tags-plugin.h
@@ -28,7 +28,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_INSERT_TAGS_PLUGIN (gtranslator_insert_tags_get_type ())
+#define GTR_TYPE_INSERT_TAGS_PLUGIN (gtr_insert_tags_get_type ())
#define GTR_INSERT_TAGS_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_MESSAGEINSERT_TAGS_PLUGIN, GtrInsertTagsPlugin))
#define GTR_INSERT_TAGS_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_INSERT_TAGS_PLUGIN, GtrInsertTagsPluginClass))
#define GTR_IS_INSERT_TAGS_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_INSERT_TAGS_PLUGIN))
@@ -63,11 +63,11 @@ struct _GtrInsertTagsPluginClass
* Public methods
*/
GType
-gtranslator_insert_tags_plugin_get_type (void)
+gtr_insert_tags_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_INSERT_TAGS_PLUGIN_H__ */
diff --git a/plugins/open-tran/gtr-open-tran-panel.c b/plugins/open-tran/gtr-open-tran-panel.c
index f27298e..1c49dd2 100644
--- a/plugins/open-tran/gtr-open-tran-panel.c
+++ b/plugins/open-tran/gtr-open-tran-panel.c
@@ -49,7 +49,7 @@
#define OPEN_OFFICE_ICON PIXMAPSDIR"/oo-logo.png"
#define FEDORA_ICON PIXMAPSDIR"/fedora.png"
-GTR_PLUGIN_DEFINE_TYPE (GtrOpenTranPanel, gtranslator_open_tran_panel,
+GTR_PLUGIN_DEFINE_TYPE (GtrOpenTranPanel, gtr_open_tran_panel,
GTK_TYPE_VBOX)
struct _GtrOpenTranPanelPrivate
@@ -347,7 +347,7 @@ entry_activate_cb (GtkEntry * entry, GtrOpenTranPanel * panel)
}
static void
-gtranslator_open_tran_panel_draw_treeview (GtrOpenTranPanel * panel)
+gtr_open_tran_panel_draw_treeview (GtrOpenTranPanel * panel)
{
GtkTreeViewColumn *column;
GtkCellRenderer *renderer;
@@ -388,7 +388,7 @@ gtranslator_open_tran_panel_draw_treeview (GtrOpenTranPanel * panel)
}
static void
-gtranslator_open_tran_panel_draw (GtrOpenTranPanel * panel)
+gtr_open_tran_panel_draw (GtrOpenTranPanel * panel)
{
GtkWidget *scrolledwindow;
GtkWidget *button;
@@ -407,7 +407,7 @@ gtranslator_open_tran_panel_draw (GtrOpenTranPanel * panel)
/*
* TreeView
*/
- gtranslator_open_tran_panel_draw_treeview (panel);
+ gtr_open_tran_panel_draw_treeview (panel);
gtk_container_add (GTK_CONTAINER (scrolledwindow), panel->priv->treeview);
/*
@@ -430,7 +430,7 @@ gtranslator_open_tran_panel_draw (GtrOpenTranPanel * panel)
}
static void
-gtranslator_open_tran_panel_init (GtrOpenTranPanel * panel)
+gtr_open_tran_panel_init (GtrOpenTranPanel * panel)
{
panel->priv = GTR_OPEN_TRAN_PANEL_GET_PRIVATE (panel);
@@ -438,11 +438,11 @@ gtranslator_open_tran_panel_init (GtrOpenTranPanel * panel)
panel->priv->gconf_client = gconf_client_get_default ();
panel->priv->session = soup_session_async_new ();
- gtranslator_open_tran_panel_draw (panel);
+ gtr_open_tran_panel_draw (panel);
}
static void
-gtranslator_open_tran_panel_dispose (GObject * object)
+gtr_open_tran_panel_dispose (GObject * object)
{
GtrOpenTranPanel *panel = GTR_OPEN_TRAN_PANEL (object);
@@ -451,21 +451,21 @@ gtranslator_open_tran_panel_dispose (GObject * object)
g_object_unref (panel->priv->session);
panel->priv->session = NULL;
}
- G_OBJECT_CLASS (gtranslator_open_tran_panel_parent_class)->dispose (object);
+ G_OBJECT_CLASS (gtr_open_tran_panel_parent_class)->dispose (object);
}
static void
-gtranslator_open_tran_panel_class_init (GtrOpenTranPanelClass * klass)
+gtr_open_tran_panel_class_init (GtrOpenTranPanelClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
g_type_class_add_private (klass, sizeof (GtrOpenTranPanelPrivate));
- object_class->dispose = gtranslator_open_tran_panel_dispose;
+ object_class->dispose = gtr_open_tran_panel_dispose;
}
GtkWidget *
-gtranslator_open_tran_panel_new (GtrWindow * window)
+gtr_open_tran_panel_new (GtrWindow * window)
{
GtrOpenTranPanel *panel;
diff --git a/plugins/open-tran/gtr-open-tran-panel.h b/plugins/open-tran/gtr-open-tran-panel.h
index aee5e0c..be7e05e 100644
--- a/plugins/open-tran/gtr-open-tran-panel.h
+++ b/plugins/open-tran/gtr-open-tran-panel.h
@@ -29,14 +29,14 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_OPEN_TRAN_PANEL (gtranslator_open_tran_panel_get_type ())
+#define GTR_TYPE_OPEN_TRAN_PANEL (gtr_open_tran_panel_get_type ())
#define GTR_OPEN_TRAN_PANEL(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_OPEN_TRAN_PANEL, GtrOpenTranPanel))
#define GTR_OPEN_TRAN_PANEL_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_OPEN_TRAN_PANEL, GtrOpenTranPanelClass))
#define GTR_IS_OPEN_TRAN_PANEL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_OPEN_TRAN_PANEL))
#define GTR_IS_OPEN_TRAN_PANEL_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), GTR_TYPE_OPEN_TRAN_PANEL))
#define GTR_OPEN_TRAN_PANEL_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), GTR_TYPE_OPEN_TRAN_PANEL, GtrOpenTranPanelClass))
/* Gconf keys */
-#define OPEN_TRAN_BASE_KEY "/apps/gtranslator/plugins/open-tran"
+#define OPEN_TRAN_BASE_KEY "/apps/gtr/plugins/open-tran"
#define SEARCH_CODE_KEY OPEN_TRAN_BASE_KEY "/search_code"
#define OWN_CODE_KEY OPEN_TRAN_BASE_KEY "/own_code"
/* Private structure type */
@@ -70,10 +70,10 @@ struct _GtrOpenTranPanelClass
* Public methods
*/
GType
-gtranslator_open_tran_panel_get_type (void)
+gtr_open_tran_panel_get_type (void)
G_GNUC_CONST;
- GType gtranslator_open_tran_panel_register_type (GTypeModule * module);
- GtkWidget *gtranslator_open_tran_panel_new (GtrWindow * window);
+ GType gtr_open_tran_panel_register_type (GTypeModule * module);
+ GtkWidget *gtr_open_tran_panel_new (GtrWindow * window);
G_END_DECLS
#endif /* __OPEN_TRAN_PANEL_H__ */
diff --git a/plugins/open-tran/gtr-open-tran-plugin.c b/plugins/open-tran/gtr-open-tran-plugin.c
index ae4ef11..9037a2f 100644
--- a/plugins/open-tran/gtr-open-tran-plugin.c
+++ b/plugins/open-tran/gtr-open-tran-plugin.c
@@ -59,10 +59,10 @@ typedef struct
} WindowData;
GTR_PLUGIN_REGISTER_TYPE_WITH_CODE (GtrOpenTranPlugin,
- gtranslator_open_tran_plugin,
- gtranslator_open_tran_panel_register_type
+ gtr_open_tran_plugin,
+ gtr_open_tran_panel_register_type
(module);)
- static void gtranslator_open_tran_plugin_init (GtrOpenTranPlugin
+ static void gtr_open_tran_plugin_init (GtrOpenTranPlugin
* plugin)
{
plugin->priv = GTR_OPEN_TRAN_PLUGIN_GET_PRIVATE (plugin);
@@ -75,7 +75,7 @@ GTR_PLUGIN_REGISTER_TYPE_WITH_CODE (GtrOpenTranPlugin,
}
static void
-gtranslator_open_tran_plugin_finalize (GObject * object)
+gtr_open_tran_plugin_finalize (GObject * object)
{
GtrOpenTranPlugin *plugin = GTR_OPEN_TRAN_PLUGIN (object);
@@ -83,7 +83,7 @@ gtranslator_open_tran_plugin_finalize (GObject * object)
g_object_unref (G_OBJECT (plugin->priv->gconf_client));
- G_OBJECT_CLASS (gtranslator_open_tran_plugin_parent_class)->
+ G_OBJECT_CLASS (gtr_open_tran_plugin_parent_class)->
finalize (object);
}
@@ -93,13 +93,13 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
{
GtkWidget *opentran;
- gtranslator_application_register_icon (GTR_APP, "open-tran.png",
+ gtr_application_register_icon (GTR_APP, "open-tran.png",
"open-tran-plugin-icon");
- opentran = gtranslator_open_tran_panel_new (window);
+ opentran = gtr_open_tran_panel_new (window);
gtk_widget_show (opentran);
- gtranslator_window_add_widget (window,
+ gtr_window_add_widget (window,
opentran,
"GtrOpenTranPlugin",
_("Open Tran"),
@@ -118,7 +118,7 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
WINDOW_DATA_KEY);
g_return_if_fail (opentran != NULL);
- gtranslator_window_remove_widget (window, opentran);
+ gtr_window_remove_widget (window, opentran);
g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
}
@@ -163,8 +163,8 @@ get_configuration_dialog (GtrOpenTranPlugin * plugin)
NULL
};
- path = gtranslator_dirs_get_ui_file ("gtr-open-tran-dialog.ui");
- ret = gtranslator_utils_get_ui_objects (path,
+ path = gtr_dirs_get_ui_file ("gtr-open-tran-dialog.ui");
+ ret = gtr_utils_get_ui_objects (path,
root_objects,
&error_widget,
"dialog", &plugin->priv->dialog,
@@ -253,13 +253,13 @@ impl_create_configure_dialog (GtrPlugin * plugin)
}
static void
-gtranslator_open_tran_plugin_class_init (GtrOpenTranPluginClass *
+gtr_open_tran_plugin_class_init (GtrOpenTranPluginClass *
klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_open_tran_plugin_finalize;
+ object_class->finalize = gtr_open_tran_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/open-tran/gtr-open-tran-plugin.h b/plugins/open-tran/gtr-open-tran-plugin.h
index 08c91eb..51026c7 100644
--- a/plugins/open-tran/gtr-open-tran-plugin.h
+++ b/plugins/open-tran/gtr-open-tran-plugin.h
@@ -28,7 +28,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_OPEN_TRAN_PLUGIN (gtranslator_open_tran_plugin_get_type ())
+#define GTR_TYPE_OPEN_TRAN_PLUGIN (gtr_open_tran_plugin_get_type ())
#define GTR_OPEN_TRAN_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_OPEN_TRAN_PLUGIN, GtrOpenTranPlugin))
#define GTR_OPEN_TRAN_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_OPEN_TRAN_PLUGIN, GtrOpenTranPluginClass))
#define GTR_IS_OPEN_TRAN_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_OPEN_TRAN_PLUGIN))
@@ -65,11 +65,11 @@ struct _GtrOpenTranPluginClass
* Public methods
*/
GType
-gtranslator_open_tran_plugin_get_type (void)
+gtr_open_tran_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_OPEN_TRAN_PLUGIN_H__ */
diff --git a/plugins/source-code-view/gtr-source-code-view-plugin.c b/plugins/source-code-view/gtr-source-code-view-plugin.c
index 06671cb..aeb25b5 100644
--- a/plugins/source-code-view/gtr-source-code-view-plugin.c
+++ b/plugins/source-code-view/gtr-source-code-view-plugin.c
@@ -35,7 +35,7 @@
#include <ctype.h>
/* Gconf keys */
-#define SOURCE_CODE_VIEW_BASE_KEY "/apps/gtranslator/plugins/source-view"
+#define SOURCE_CODE_VIEW_BASE_KEY "/apps/gtr/plugins/source-view"
#define USE_EDITOR_KEY SOURCE_CODE_VIEW_BASE_KEY "/use_editor"
#define PROGRAM_CMD_KEY SOURCE_CODE_VIEW_BASE_KEY "/program_cmd"
#define LINE_CMD_KEY SOURCE_CODE_VIEW_BASE_KEY "/line_cmd"
@@ -64,7 +64,7 @@ struct _GtrSourceCodeViewPluginPrivate
};
GTR_PLUGIN_REGISTER_TYPE (GtrSourceCodeViewPlugin,
- gtranslator_source_code_view_plugin)
+ gtr_source_code_view_plugin)
static void insert_link (GtkTextBuffer * buffer, GtkTextIter * iter,
const gchar * path, gint * line,
GtrSourceCodeViewPlugin * plugin,
@@ -153,7 +153,7 @@ show_source (GtrSourceCodeViewPlugin * plugin,
g_free (line_cmd);
}
else
- gtranslator_show_viewer (plugin->priv->window, path, line);
+ gtr_show_viewer (plugin->priv->window, path, line);
}
static gboolean
@@ -223,13 +223,13 @@ follow_if_link (GtrSourceCodeViewPlugin * plugin,
gchar *dirname;
GFile *location, *parent;
- tab = gtranslator_window_get_active_tab (plugin->priv->window);
+ tab = gtr_window_get_active_tab (plugin->priv->window);
if (!tab)
return;
- po = gtranslator_tab_get_po (tab);
+ po = gtr_tab_get_po (tab);
- location = gtranslator_po_get_location (po);
+ location = gtr_po_get_location (po);
parent = g_file_get_parent (location);
g_object_unref (location);
@@ -390,7 +390,7 @@ visibility_notify_event (GtkWidget * text_view, GdkEventVisibility * event)
}
static void
-gtranslator_source_code_view_plugin_init (GtrSourceCodeViewPlugin *
+gtr_source_code_view_plugin_init (GtrSourceCodeViewPlugin *
plugin)
{
plugin->priv = GTR_SOURCE_CODE_VIEW_PLUGIN_GET_PRIVATE (plugin);
@@ -405,7 +405,7 @@ gtranslator_source_code_view_plugin_init (GtrSourceCodeViewPlugin *
}
static void
-gtranslator_source_code_view_plugin_finalize (GObject * object)
+gtr_source_code_view_plugin_finalize (GObject * object)
{
GtrSourceCodeViewPlugin *plugin =
GTR_SOURCE_CODE_VIEW_PLUGIN (object);
@@ -414,7 +414,7 @@ gtranslator_source_code_view_plugin_finalize (GObject * object)
g_object_unref (G_OBJECT (plugin->priv->gconf_client));
- G_OBJECT_CLASS (gtranslator_source_code_view_plugin_parent_class)->
+ G_OBJECT_CLASS (gtr_source_code_view_plugin_parent_class)->
finalize (object);
}
@@ -432,8 +432,8 @@ showed_message_cb (GtrTab * tab,
GtrContextPanel *panel;
GtkTextMark *path_start, *path_end;
- panel = gtranslator_tab_get_context_panel (tab);
- view = gtranslator_context_panel_get_context_text_view (panel);
+ panel = gtr_tab_get_context_panel (tab);
+ view = gtr_context_panel_get_context_text_view (panel);
buffer = gtk_text_view_get_buffer (view);
@@ -443,14 +443,14 @@ showed_message_cb (GtrTab * tab,
"path_start", &iter, TRUE);
gtk_text_buffer_insert (buffer, &iter, _("Paths:\n"), -1);
- filename = gtranslator_msg_get_filename (msg, i);
+ filename = gtr_msg_get_filename (msg, i);
while (filename)
{
- line = gtranslator_msg_get_file_line (msg, i);
+ line = gtr_msg_get_file_line (msg, i);
insert_link (buffer, &iter, filename, line, plugin,
- gtranslator_msg_get_msgid (msg));
+ gtr_msg_get_msgid (msg));
i++;
- filename = gtranslator_msg_get_filename (msg, i);
+ filename = gtr_msg_get_filename (msg, i);
}
/*
@@ -473,8 +473,8 @@ delete_text_and_tags (GtrTab * tab,
GtkTextIter start, end;
GtkTextMark *path_start, *path_end;
- panel = gtranslator_tab_get_context_panel (tab);
- view = gtranslator_context_panel_get_context_text_view (panel);
+ panel = gtr_tab_get_context_panel (tab);
+ view = gtr_context_panel_get_context_text_view (panel);
buffer = gtk_text_view_get_buffer (view);
path_start = gtk_text_buffer_get_mark (buffer, "path_start");
@@ -528,8 +528,8 @@ page_added_cb (GtkNotebook * notebook,
GtrContextPanel *panel;
GtkTextView *view;
- panel = gtranslator_tab_get_context_panel (GTR_TAB (child));
- view = gtranslator_context_panel_get_context_text_view (panel);
+ panel = gtr_tab_get_context_panel (GTR_TAB (child));
+ view = gtr_context_panel_get_context_text_view (panel);
g_return_if_fail (GTK_IS_TEXT_VIEW (view));
@@ -567,8 +567,8 @@ get_configuration_dialog (GtrSourceCodeViewPlugin * plugin)
NULL
};
- path = gtranslator_dirs_get_ui_file ("gtr-source-code-view-dialog.ui");
- ret = gtranslator_utils_get_ui_objects (path,
+ path = gtr_dirs_get_ui_file ("gtr-source-code-view-dialog.ui");
+ ret = gtr_utils_get_ui_objects (path,
root_objects,
&error_widget,
"dialog", &plugin->priv->dialog,
@@ -639,7 +639,7 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
hand_cursor = gdk_cursor_new (GDK_HAND2);
regular_cursor = gdk_cursor_new (GDK_XTERM);
- notebook = GTK_WIDGET (gtranslator_window_get_notebook (window));
+ notebook = GTK_WIDGET (gtr_window_get_notebook (window));
source_code_view->priv->window = window;
@@ -649,7 +649,7 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
/*
* If we already have tabs opened we have to add them
*/
- tabs = gtranslator_window_get_all_tabs (window);
+ tabs = gtr_window_get_all_tabs (window);
for (l = tabs; l != NULL; l = g_list_next (l))
{
GtrPo *po;
@@ -658,8 +658,8 @@ impl_activate (GtrPlugin * plugin, GtrWindow * window)
page_added_cb (GTK_NOTEBOOK (notebook),
l->data, 0, GTR_SOURCE_CODE_VIEW_PLUGIN (plugin));
- po = gtranslator_tab_get_po (GTR_TAB (l->data));
- msg = gtranslator_po_get_current_message (po);
+ po = gtr_tab_get_po (GTR_TAB (l->data));
+ msg = gtr_po_get_current_message (po);
showed_message_cb (GTR_TAB (l->data),
msg->data, GTR_SOURCE_CODE_VIEW_PLUGIN (plugin));
@@ -674,13 +674,13 @@ impl_deactivate (GtrPlugin * plugin, GtrWindow * window)
GtrContextPanel *panel;
GtkWidget *notebook;
- tabs = gtranslator_window_get_all_tabs (window);
- notebook = GTK_WIDGET (gtranslator_window_get_notebook (window));
+ tabs = gtr_window_get_all_tabs (window);
+ notebook = GTK_WIDGET (gtr_window_get_notebook (window));
for (l = tabs; l != NULL; l = g_list_next (l))
{
- panel = gtranslator_tab_get_context_panel (GTR_TAB (l->data));
- view = gtranslator_context_panel_get_context_text_view (panel);
+ panel = gtr_tab_get_context_panel (GTR_TAB (l->data));
+ view = gtr_context_panel_get_context_text_view (panel);
delete_text_and_tags (GTR_TAB (l->data),
GTR_SOURCE_CODE_VIEW_PLUGIN (plugin));
@@ -774,13 +774,13 @@ impl_create_configure_dialog (GtrPlugin * plugin)
}
static void
-gtranslator_source_code_view_plugin_class_init
+gtr_source_code_view_plugin_class_init
(GtrSourceCodeViewPluginClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
GtrPluginClass *plugin_class = GTR_PLUGIN_CLASS (klass);
- object_class->finalize = gtranslator_source_code_view_plugin_finalize;
+ object_class->finalize = gtr_source_code_view_plugin_finalize;
plugin_class->activate = impl_activate;
plugin_class->deactivate = impl_deactivate;
diff --git a/plugins/source-code-view/gtr-source-code-view-plugin.h b/plugins/source-code-view/gtr-source-code-view-plugin.h
index bded10f..1980700 100644
--- a/plugins/source-code-view/gtr-source-code-view-plugin.h
+++ b/plugins/source-code-view/gtr-source-code-view-plugin.h
@@ -28,7 +28,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_SOURCE_CODE_VIEW_PLUGIN (gtranslator_source_code_view_plugin_get_type ())
+#define GTR_TYPE_SOURCE_CODE_VIEW_PLUGIN (gtr_source_code_view_plugin_get_type ())
#define GTR_SOURCE_CODE_VIEW_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_SOURCE_CODE_VIEW_PLUGIN, GtrSourceCodeViewPlugin))
#define GTR_SOURCE_CODE_VIEW_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_SOURCE_CODE_VIEW_PLUGIN, GtrSourceCodeViewPluginClass))
#define GTR_IS_SOURCE_CODE_VIEW_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_SOURCE_CODE_VIEW_PLUGIN))
@@ -67,11 +67,11 @@ struct _GtrSourceCodeViewPluginClass
* Public methods
*/
GType
-gtranslator_source_code_view_plugin_get_type (void)
+gtr_source_code_view_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_SOURCE_CODE_VIEW_PLUGIN_H__ */
diff --git a/plugins/source-code-view/gtr-viewer.c b/plugins/source-code-view/gtr-viewer.c
index 3d93c92..2c94c72 100644
--- a/plugins/source-code-view/gtr-viewer.c
+++ b/plugins/source-code-view/gtr-viewer.c
@@ -39,7 +39,7 @@
GtrViewerPrivate))
-G_DEFINE_TYPE (GtrViewer, gtranslator_viewer, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE (GtrViewer, gtr_viewer, GTK_TYPE_DIALOG)
struct _GtrViewerPrivate
{
GtkWidget *main_box;
@@ -57,7 +57,7 @@ G_DEFINE_TYPE (GtrViewer, gtranslator_viewer, GTK_TYPE_DIALOG)
}
static void
-gtranslator_viewer_init (GtrViewer * dlg)
+gtr_viewer_init (GtrViewer * dlg)
{
gboolean ret;
GtkWidget *error_widget;
@@ -90,8 +90,8 @@ gtranslator_viewer_init (GtrViewer * dlg)
"response", G_CALLBACK (dialog_response_handler), NULL);
/*Builder */
- path = gtranslator_dirs_get_ui_file ("gtr-viewer.ui");
- ret = gtranslator_utils_get_ui_objects (path,
+ path = gtr_dirs_get_ui_file ("gtr-viewer.ui");
+ ret = gtr_utils_get_ui_objects (path,
root_objects,
&error_widget,
"main_box", &dlg->priv->main_box,
@@ -131,19 +131,19 @@ gtranslator_viewer_init (GtrViewer * dlg)
}
static void
-gtranslator_viewer_finalize (GObject * object)
+gtr_viewer_finalize (GObject * object)
{
- G_OBJECT_CLASS (gtranslator_viewer_parent_class)->finalize (object);
+ G_OBJECT_CLASS (gtr_viewer_parent_class)->finalize (object);
}
static void
-gtranslator_viewer_class_init (GtrViewerClass * klass)
+gtr_viewer_class_init (GtrViewerClass * klass)
{
GObjectClass *object_class = G_OBJECT_CLASS (klass);
g_type_class_add_private (klass, sizeof (GtrViewerPrivate));
- object_class->finalize = gtranslator_viewer_finalize;
+ object_class->finalize = gtr_viewer_finalize;
}
/***************** File loading *****************/
@@ -416,7 +416,7 @@ jump_to_line (GtkTextView * view, gint line)
}
void
-gtranslator_show_viewer (GtrWindow * window,
+gtr_show_viewer (GtrWindow * window,
const gchar * path, gint line)
{
static GtrViewer *dlg = NULL;
diff --git a/plugins/source-code-view/gtr-viewer.h b/plugins/source-code-view/gtr-viewer.h
index 0d3334c..b296467 100644
--- a/plugins/source-code-view/gtr-viewer.h
+++ b/plugins/source-code-view/gtr-viewer.h
@@ -29,7 +29,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_VIEWER (gtranslator_viewer_get_type ())
+#define GTR_TYPE_VIEWER (gtr_viewer_get_type ())
#define GTR_VIEWER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_VIEWER, GtrViewer))
#define GTR_VIEWER_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_VIEWER, GtrViewerClass))
#define GTR_IS_VIEWER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_VIEWER))
@@ -65,12 +65,12 @@ struct _GtrViewerClass
* Public methods
*/
GType
-gtranslator_viewer_get_type (void)
+gtr_viewer_get_type (void)
G_GNUC_CONST;
- GType gtranslator_viewer_register_type (GTypeModule * module);
+ GType gtr_viewer_register_type (GTypeModule * module);
- void gtranslator_show_viewer (GtrWindow * window,
+ void gtr_show_viewer (GtrWindow * window,
const gchar * path, gint line);
G_END_DECLS
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/plugins/charmap/gtr-charmap-panel.h b/plugins/charmap/gtr-charmap-panel.h
index ade8913..e6f1a8d 100644
--- a/plugins/charmap/gtr-charmap-panel.h
+++ b/plugins/charmap/gtr-charmap-panel.h
@@ -1,21 +1,21 @@
/*
* charmap-panel.h
* This file is part of gtranslator
*
* Copyright (C) 2006 - Steve Frécinaux
*
* gtranslator is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* gtranslator is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with gtranslator; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA 02110-1301 USA
*/
@@ -37,7 +37,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_CHARMAP_PANEL (gtranslator_charmap_panel_get_type ())
+#define GTR_TYPE_CHARMAP_PANEL (gtr_charmap_panel_get_type ())
#define GTR_CHARMAP_PANEL(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_CHARMAP_PANEL, GtrCharmapPanel))
#define GTR_CHARMAP_PANEL_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_CHARMAP_PANEL, GtrCharmapPanelClass))
#define GTR_IS_CHARMAP_PANEL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_CHARMAP_PANEL))
@@ -73,18 +73,18 @@ struct _GtrCharmapPanelClass
* Public methods
*/
GType
-gtranslator_charmap_panel_get_type (void)
+gtr_charmap_panel_get_type (void)
G_GNUC_CONST;
- GType gtranslator_charmap_panel_register_type (GTypeModule * module);
- GtkWidget *gtranslator_charmap_panel_new (void);
+ GType gtr_charmap_panel_register_type (GTypeModule * module);
+ GtkWidget *gtr_charmap_panel_new (void);
#ifdef HAVE_GUCHARMAP_2
GucharmapChartable
- *gtranslator_charmap_panel_get_chartable (GtrCharmapPanel *
+ *gtr_charmap_panel_get_chartable (GtrCharmapPanel *
panel);
#else
GucharmapTable
- *gtranslator_charmap_panel_get_table (GtrCharmapPanel * panel);
+ *gtr_charmap_panel_get_table (GtrCharmapPanel * panel);
#endif
G_END_DECLS
@@ -1,21 +1,21 @@
/*
* charmap-panel.h
- * This file is part of gtranslator
+ * This file is part of gtr
*
* Copyright (C) 2006 - Steve Frécinaux
@@ -1,21 +1,21 @@
* Copyright (C) 2006 - Steve Frécinaux
*
- * gtranslator is free software; you can redistribute it and/or modify
+ * gtr is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,21 +1,21 @@
* (at your option) any later version.
*
- * gtranslator is distributed in the hope that it will be useful,
+ * gtr is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -1,21 +1,21 @@
*
* You should have received a copy of the GNU General Public License
- * along with gtranslator; if not, write to the Free Software
+ * along with gtr; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA 02110-1301 USA
diff --git a/plugins/charmap/gtr-charmap-plugin.h b/plugins/charmap/gtr-charmap-plugin.h
index 870e07f..4ab5c39 100644
--- a/plugins/charmap/gtr-charmap-plugin.h
+++ b/plugins/charmap/gtr-charmap-plugin.h
@@ -1,5 +1,5 @@
/*
* gtranslator-charmap-plugin.h - Character map side-pane for gtranslator
*
* Copyright (C) 2006 Steve Frécinaux
*
@@ -17,7 +17,7 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*
- * $Id: gtranslator-charmap-plugin.h 137 2006-04-23 15:13:27Z sfre $
+ * $Id: gtr-charmap-plugin.h 137 2006-04-23 15:13:27Z sfre $
*/
#ifndef __GTR_CHARMAP_PLUGIN_H__
@@ -31,7 +31,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_CHARMAP_PLUGIN (gtranslator_charmap_plugin_get_type ())
+#define GTR_TYPE_CHARMAP_PLUGIN (gtr_charmap_plugin_get_type ())
#define GTR_CHARMAP_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_CHARMAP_PLUGIN, GtrCharmapPlugin))
#define GTR_CHARMAP_PLUGIN_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_CHARMAP_PLUGIN, GtrCharmapPluginClass))
#define GTR_IS_CHARMAP_PLUGIN(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_CHARMAP_PLUGIN))
@@ -65,11 +65,11 @@ struct _GtrCharmapPluginClass
* Public methods
*/
GType
-gtranslator_charmap_plugin_get_type (void)
+gtr_charmap_plugin_get_type (void)
G_GNUC_CONST;
/* All the plugins must implement this function */
- G_MODULE_EXPORT GType register_gtranslator_plugin (GTypeModule * module);
+ G_MODULE_EXPORT GType register_gtr_plugin (GTypeModule * module);
G_END_DECLS
#endif /* __GTR_CHARMAP_PLUGIN_H__ */
@@ -1,5 +1,5 @@
/*
- * gtranslator-charmap-plugin.h - Character map side-pane for gtranslator
+ * gtr-charmap-plugin.h - Character map side-pane for gtr
*
* Copyright (C) 2006 Steve Frécinaux
diff --git a/plugins/glossary/glossary-panel.h b/plugins/glossary/glossary-panel.h
index 79f2e03..3470c68 100644
--- a/plugins/glossary/glossary-panel.h
+++ b/plugins/glossary/glossary-panel.h
@@ -1,22 +1,22 @@
/*
* glossary-panel.h
* This file is part of gtranslator
*
* Copyright (C) 2006 - Steve Frécinaux
* 2007 - Ignacio Casal Quinteiro <nacho resa gmail com>
*
* gtranslator is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* gtranslator is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with gtranslator; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA 02110-1301 USA
*/
@@ -32,7 +32,7 @@ G_BEGIN_DECLS
/*
* Type checking and casting macros
*/
-#define GTR_TYPE_GLOSSARY_PANEL (gtranslator_glossary_panel_get_type ())
+#define GTR_TYPE_GLOSSARY_PANEL (gtr_glossary_panel_get_type ())
#define GTR_GLOSSARY_PANEL(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_GLOSSARY_PANEL, GtrGlossaryPanel))
#define GTR_GLOSSARY_PANEL_CLASS(k) (G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_GLOSSARY_PANEL, GtrGlossaryPanelClass))
#define GTR_IS_GLOSSARY_PANEL(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_GLOSSARY_PANEL))
@@ -69,10 +69,10 @@ struct _GtrGlossaryPanelClass
* Public methods
*/
GType
-gtranslator_glossary_panel_get_type (void)
+gtr_glossary_panel_get_type (void)
G_GNUC_CONST;
- GType gtranslator_glossary_panel_register_type (GTypeModule * module);
- GtkWidget *gtranslator_glossary_panel_new (void);
+ GType gtr_glossary_panel_register_type (GTypeModule * module);
+ GtkWidget *gtr_glossary_panel_new (void);
G_END_DECLS
#endif /* __GLOSSARY_PANEL_H__ */
@@ -1,22 +1,22 @@
/*
* glossary-panel.h
- * This file is part of gtranslator
+ * This file is part of gtr
*
* Copyright (C) 2006 - Steve Frécinaux
@@ -1,22 +1,22 @@
* 2007 - Ignacio Casal Quinteiro <nacho resa gmail com>
*
- * gtranslator is free software; you can redistribute it and/or modify
+ * gtr is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
@@ -1,22 +1,22 @@
* (at your option) any later version.
*
- * gtranslator is distributed in the hope that it will be useful,
+ * gtr is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -1,22 +1,22 @@
*
* You should have received a copy of the GNU General Public License
- * along with gtranslator; if not, write to the Free Software
+ * along with gtr; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor,
* Boston, MA 02110-1301 USA